@@ -1,20 +1,20 @@
-from vtkplotter import Plotter
+from vedo import Plotter
 
 from morphapi.morphology.morphology import Neuron
 
 """
-    This example shows how to use vtkplotter to visualise a 3d reconstruction of a neuron.
+    This example shows how to use vedo to visualise a 3d reconstruction of a neuron.
     However, the reccomended way to visualise neurons is with brainrender:
     https://github.com/BrancoLab/BrainRender
 """
 
 fp = "examples/example_files/example1.swc"
 
-# Create vtkplotter actors from the .swc file
-neuron = Neuron(swc_file=fp)
+# Create vedo actors from the .swc file
+neuron = Neuron(data_file=fp)
 components, neuron = neuron.create_mesh(
     neurite_radius=3,  #
-    soma_color="salmon",  # Specify colors [see vtkplotter.colors for more details]
+    soma_color="salmon",  # Specify colors [see vedo.colors for more details]
     apical_dendrites_color="darkseagreen",
     basal_dendrites_color="orangered",
     axon_color="blackboard",
